@@ -220,10 +220,10 @@ function check4NecessaryDBUpdates() {
             }
             $dbExistingVersion = 5;
         }
-        
+
         if ($dbExistingVersion == 5) {
             logIntoFile("Updating DB-Model: 5 --> 6");
-            
+
             if ($usedb == "oracle") {
                 $sQuery = "COMMENT ON COLUMN OPLIST.OPDELETED IS '1: geloeschter OP-Punkt, sonst 0'";
                 debugIntoFile("Update-Select1=".$sQuery);
@@ -280,7 +280,7 @@ function check4NecessaryDBUpdates() {
             }
             $dbExistingVersion = 6;
         }
-        
+
         if ($dbExistingVersion == 6) {
             logIntoFile("Updating DB-Model: 6 --> 7");
 
@@ -292,6 +292,29 @@ function check4NecessaryDBUpdates() {
             $dbExistingVersion = 7;
         }
 
+        if ($dbExistingVersion == 7) {
+            logIntoFile("Updating DB-Model: 7 --> 8");
+
+            if ($usedb == "mysql") {
+                $sQuery = "ALTER TABLE OPLIST ADD OPDEADLINE2 DATE COMMENT 'Termin'";
+                debugIntoFile("Update-Select1=".$sQuery);
+                getRessource($sQuery);
+                logSQLError();
+            } else {
+                $sQuery = "ALTER TABLE OPLIST ADD OPDEADLINE DATE";
+                debugIntoFile("Update-Select1=".$sQuery);
+                getRessource($sQuery);
+                logSQLError();
+
+                $sQuery = "COMMENT ON COLUMN OPLIST.OPDEADLINE IS 'Termin'";
+                getRessource($sQuery);
+                logSQLError();
+            }
+
+
+            $dbExistingVersion = 8;
+        }
+
         # update version
         $sQuery = "UPDATE OPLIST_VERSION SET OPVVERSION=".$databaseMinVersion.", OPVDESC='".$myVersion.".".$SVNRevision."' WHERE OPVID = 1";
         debugIntoFile("Update-Select=".$sQuery);
